@@ -1,6 +1,6 @@
 from .abc import Feeder, Amplifier, FilterFeeder, AmplifierFeeder
 from .abc import Downloader, FilterDownloader, CallbackDownloader, FilterCallbackDownloader
-from .abc import Filter, Callback, Branch
+from .abc import Filter, Callback, Branch, Root, MultiRoot
 from .abc import Logger
 from .update import UpdateRW, UpdateDownloader
 from .controller import Pair, Controller
